projectal.dynamic_enums.complexity_levels API documentation

# projectal.dynamic_enums.complexity_levels

View Source

    1from projectal.dynamic_enum import DynamicEnum
    2
    3
    4class ComplexityLevels(DynamicEnum):
    5    _name = "GanttComplexityEnum"

class ComplexityLevels(projectal.dynamic_enum.DynamicEnum): View Source

    5class ComplexityLevels(DynamicEnum):
    6    _name = "GanttComplexityEnum"

##### Inherited Members

projectal.dynamic_enum.DynamicEnum
  get
  set